<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="2.0">
    
    <!-- SIMILE Widget Timeline 
    interaktive Zeitleiste, die in Webseiten eingebunden werden kann 
    man braucht JS
    "Google Maps" for time 
    
    - eine oder mehrere "Bands", die gezogen und synchronisiert werden können
    -->
    <xsl:output method="xhtml" encoding="UTF-8" />
    
    <xsl:template match="/">
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <style type="text/css">
                    body {
                        font-family: sans-serif;
                        font-size: 10pt;
                    }
                </style>
                <script src="http://api.simile-widgets.org/timeline/2.3.1/timeline-api.js?bundle=true" type="text/javascript"></script>
                <script type="text/javascript">
                    var tl;
                    /* 
                    - wenn die Timeline-API geladen ist, wird die Timeline konstruiert
                    - hier werden zwei "Bänder" erstellt: 
                    das obere mit Monaten in 100px-Abständen und einer Höhe von 70%
                    und das untere mit Jahren in 200px-Abständen und einer Höhe von 30%
                    - beide können unabhängig voneinander bewegt werden
                    */
                    function onLoad() {
                    /* Objekt für Events hinzufügen */
                      var eventSource = new Timeline.DefaultEventSource();
                      var bandInfos = [
                        Timeline.createBandInfo({
                            date:           "1684",
                            width:          "10%", 
                            intervalUnit:   Timeline.DateTime.DECADE, 
                            intervalPixels: 150
                        }),
                        Timeline.createBandInfo({
                            date:           "1684",
                            width:          "10%", 
                            intervalUnit:   Timeline.DateTime.DECADE, 
                            intervalPixels: 400
                        }),
                        Timeline.createBandInfo({
                            eventSource:    eventSource,
                            date:           "1684",
                            width:          "70%", 
                            intervalUnit:   Timeline.DateTime.YEAR, 
                            intervalPixels: 100
                        }),
                        Timeline.createBandInfo({
                            /* overview:       true,
                            eventSource:    eventSource, */
                            date:           "1684",
                            width:          "10%", 
                            intervalUnit:   Timeline.DateTime.YEAR, 
                            intervalPixels: 50
                        })
                      ];
                      /* Synchronisieren der Bänder; Hervorheben des sichtbaren Teils des oberen Bandes auf dem unteren */
                        bandInfos[0].syncWith = 2;
                        bandInfos[1].syncWith = 2;
                        bandInfos[3].syncWith = 2;
                        bandInfos[3].highlight = true;
                        bandInfos[0].highlight = true;
                        bandInfos[1].highlight = true;
                      /* Lebenszeitraum hervorheben */
                        bandInfos[0].decorators = [
                             new Timeline.SpanHighlightDecorator({
                                 startDate:  "1651-09-16",
                                 endDate:    "1716-11-02",
                                 /* startLabel: "Geburt",
                                 endLabel:   "Tod", */
                                 color:      "#FFCC33",
                                 opacity:    50
                             })
                         ];
                       /* Forschungsreise durch Russland, Persien, Indien, Java, Siam und Japan */ 
                       bandInfos[1].decorators = [
                             new Timeline.SpanHighlightDecorator({
                                 startDate:  "1683-03-20",
                                 endDate:    "1694-08",
                                 /* startLabel: "Beginn",
                                 endLabel:   "Ende", */
                                 color:      "#FF6633",
                                 opacity:    50
                             })
                         ];
    
                      tl = Timeline.create(document.getElementById("my-timeline"), bandInfos);
                      Timeline.loadXML("events.xml", function(xml, url) { eventSource.loadXML(xml, url); });
                    }
                   
                    var resizeTimerID = null;
                    function onResize() {
                        if (resizeTimerID == null) {
                            resizeTimerID = window.setTimeout(function() {
                                resizeTimerID = null;
                                tl.layout();
                            }, 500);
                        }
                    }
                    
                </script>
            </head>
            <body onload="onLoad();" onresize="onResize();">
                <div id="my-timeline" style="height: 350px; border: 1px solid #aaa"></div>
            </body>
        </html>
    </xsl:template>
    
</xsl:stylesheet>