<?xml version="1.0" encoding="UTF-8"?>
<!-- Ziel: bestehendes Ortsregister (ortsregister.xml) mit Geokoordinaten anreichern (ortsregister2.xml als Zieldatei)
    Vorgehen:
    - alles kopieren außer...
    - Ortselemente ohne Koordinatenangaben
    - die werden von Google geholt
    - und dem Register hinzugefügt
    zu beachten:
    - wahrscheinlich wurden nach dem ersten Durchlauf des Stylesheets nicht alle Koordinaten gefunden
    - man kann das Stylesheet dann (mit dem im ersten Durchlauf angepassten XML-Dokument als Ausgangspunkt, also ortsregister2.xml) erneut laufen lassen
    - solange, bis keine neuen Koordinaten mehr gefunden werden
    - evtl. manuell nachbearbeiten
-->


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:kml="http://earth.google.com/kml/2.0" xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    version="2.0" exclude-result-prefixes="kml">
    <!-- @xmlns:kml - Definition des KML-Namensraums (Keyhole Markup Language), der von Google zur Beschreibung von Geodaten verwendet wird;
         @exclude-result-prefixes - das kml-Präfix soll im Ergebnisdokument nicht ausgegeben werden 
         @xpath-default-namespace - TEI als Standardnamensraum für XPath-Abfragen (das Ausgangsdokument ist TEI!)
    -->
    
    <xsl:output method="xml"/>
    
    <!-- Variable mit dem Benutzerschlüssel, den man braucht, um Googles Geodaten-Service nutzen zu können -->
    <xsl:variable name="key" select="'ABQIAAAA6wyLPpbDp03tNqBX6NzZyRT2yXp_ZAY8_ufC3CFXhHIE1NvwkxRNs-JV0rqHP75bygTkcn_guLR8zg'"/>
    
    <!-- Variable mit der URL für den Google-Webservice
        Parameter:
        output=xml - das Ergebnis der Abfrage soll als XML zurückgegeben werden
        key= $key - Benutzerschlüssel
        q= ... - das Suchwort (der gesuchte Ort); hier noch nicht angegeben, wird später für den jeweiligen Ort hinzugefügt
    -->
    <xsl:variable name="googleurl" select="concat('http://maps.google.com/maps/geo?output=xml&amp;sensor=false&amp;key=',$key,'&amp;q=')" />
    
    <!-- copy all but...
        - Schablone für alle Knoten, Attribute, Verarbeitungsanweisungen, Kommentare
        - die jeweils kopiert werden
        - die Schablone wird für alle Kindknoten erneut aufgerufen
        - es wird nur dann NICHT kopiert, wenn es ein spezielleres Template für bestimmte Knoten gibt...
    -->
    <xsl:template match="node() | @* | processing-instruction() | comment()">
        <xsl:copy>
            <xsl:apply-templates select="node() | @* | processing-instruction() | comment()"/>
        </xsl:copy>
    </xsl:template>
    
    <!-- spezielle Schablone für Ortselemente, die noch kein <geo>-Element haben oder deren <geo>-Element leer ist 
        für diese Orte sollen Koordinaten geholt und ins Ergebnisdokument geschrieben werden
    -->
    <xsl:template match="//place[not(placeName/geo) or normalize-space(placeName/geo) = '']">
        <!-- wir bauen das Ortselement wieder auf, Achtung: der Zielnamensraum (@xmlns) ist TEI, da Ausgangs- und Ergebnisdokument ebenfalls 
            TEI-Dokumente sind/sein sollen! -->
        <place xml:id="{@xml:id}" xmlns="http://www.tei-c.org/ns/1.0">
            <placeName ref="{placeName/@ref}">
                <xsl:value-of select="placeName" />
                
                <!-- Leerzeichen im Ortsnamen werden durch + ersetzt, der Orstname wird maskiert, damit er in der Google-URL übergeben werden kann -->
                <xsl:variable name="ortsname" select="encode-for-uri(translate(placeName, ' ', '+'))" />
                
                <!-- Verknüpfung von Google-Basis-URL mit dem aktuellen Ortsnamen,
                    der Service wird mit document() aufgerufen und das Ergebnisdokument in der Variablen $geodaten gespeichert
                -->
                <xsl:variable name="geodaten" select="document(concat($googleurl, $ortsname))"/>
                
                <!-- Beispiel für das, was Google zurückliefert:
                <kml xmlns="http://earth.google.com/kml/2.0">
                    <Response>
                        <name>Aachen</name>
                        <Status>
                            <code>200</code>
                            <request>geocode</request>
                        </Status>
                        <Placemark id="p1">
                            <address>Aachen, Deutschland</address>
                            <AddressDetails xmlns="urn:oasis:names:tc:ciq:xsdschema:xAL:2.0" Accuracy="4">
                                <Country>
                                    <CountryNameCode>DE</CountryNameCode>
                                    <CountryName>Deutschland</CountryName>
                                    <AdministrativeArea>
                                        <AdministrativeAreaName>Nordrhein-Westfalen</AdministrativeAreaName>
                                        <SubAdministrativeArea>
                                            <SubAdministrativeAreaName>Köln</SubAdministrativeAreaName>
                                            <Locality>
                                                <LocalityName>Aachen</LocalityName>
                                            </Locality>
                                        </SubAdministrativeArea>
                                    </AdministrativeArea>
                                </Country>
                            </AddressDetails>
                            <ExtendedData>
                                <LatLonBox north="50.8572332" south="50.6621268" east="6.2181501" west="5.9748992"/>
                            </ExtendedData>
                            <Point>
                                <coordinates>6.0838868,50.7753455,0</coordinates>
                            </Point>
                        </Placemark>
                      </Response>
                    </kml>
                -->
                
                <!-- wir wollen den Längen- und Breitengrad aus dem coordinates-Element auslesen 
                    - Längengrad: der Teil vor dem ersten Komma
                    - Breitengrad: der Teil nach dem ersten und vor dem zweiten Komma
                -->
                <xsl:variable name="long" select="substring-before($geodaten//kml:Placemark[1]//kml:coordinates, ',')" />
                <xsl:variable name="lat" select="substring-before(substring-after($geodaten//kml:Placemark[1]//kml:coordinates, ','), ',')" />
                <!-- Geokoordinaten in Zielelement schreiben: -->
                <geo><xsl:value-of select="concat($lat, ' ', $long)" /></geo>
            </placeName>
        </place>
    </xsl:template>
    
    
</xsl:stylesheet>