<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    version="2.0">
    
    <!-- Ziel: 
         - Geografische Karte mit Google-Maps erstellen, auf Basis des Ortsregisters mit Geokoordinaten (ortsregister2.xml) 
         - Vorgehen:
            - HTML-Datei aufbauen, mit Container-Element (<div>) für die Karte
            - externe Javascript-Datei von Google einbinden
            - lokales Javascript für Google-Map erstellen (siehe Tutorial: https://developers.google.com/maps/documentation/javascript/tutorial?hl=de)
            - lokales Javascript anpassen:
                - Kartenmittelpunkt
                - Zoomfaktor
                - ...
            - mit XSLT für jeden Ort einen Marker und ein Infofenster erstellen
    -->
    
    <xsl:output method="xhtml" indent="no"/>
    
    
    <xsl:template match="/">
        <html>
            <head>
                <title>Karte</title>
                <!-- externe Javascript-Datei für Maps einbinden -->
                <script type="text/javascript" src="https://maps.google.com/maps/api/js?sensor=true"></script>
                <!-- lokaler Javascript-Teil -->
                <script type="text/javascript">  
                    /* Beispielfunktion aus dem Tutorial kopieren */
                    function initialize(){
                        //  die Koordinaten für den Kartenmittelpunkt passen wir an
                        var latlng = new google.maps.LatLng(47.5574210, 7.5925727);
                        // Anzeigeoptionen für die Karte
                        var myOptions = {
                          zoom: 6, //hier kann der Zoomfaktor angepasst werden
                          center: latlng,
                          mapTypeId: google.maps.MapTypeId.ROADMAP //hier könnte der Kartentyp angepasst werden (auch möglich: SATELLITE, HYBRID, TERRAIN)
                        };
                        /* hier wird die Karte erstellt 
                            - in document.getElementById("...") die ID des Elements angeben, in dem die Karte angezeigt werden soll -> siehe unten im HTML-Body
                        */
                        var map = new google.maps.Map(document.getElementById("container_karte"),
                            myOptions);
                         
                         // XSLT: für jeden Ort aus der Registerdatei...
                         <xsl:for-each select="//place">
                             
                            <!-- (1) wird ein Marker erstellt (var marker)
                             der für jeden Ort eindeutig sein muss, weshalb die aktuelle Position angehängt wird -->
                              var marker<xsl:value-of select="position()" /> = new google.maps.Marker({
                                 <!-- die Geokoordinaten für den aktuellen Marker einfügen (werden aus der Registerdatei ausgelesen) -->
                                 position: new google.maps.LatLng(<xsl:value-of select="substring-before(placeName/geo, ' ')" />, <xsl:value-of select="substring-after(placeName/geo, ' ')" />), 
                                 map: map, 
                                 <!-- den Ortsnamen mit XPath auslesen -->
                                 title:"<xsl:value-of select="placeName/normalize-space(text())" />"
                             });  
                             
                             <!-- (2) ... und ein Infofenster 
                             - zunächst wird der Inhalt des Infofensters definiert (in contentString), das kann, wie hier, auch HTML sein: eine Überschrift (h2), die den Ortsnamen enthält
                             -->
                            var contentString = "<h2><xsl:value-of select="normalize-space(placeName/text())" /></h2>";
                             <!-- das Infofenster muss für jeden Ort eindeutig identifiziert sein, deshalb die Positionsangabe -->
                             var infowindow<xsl:value-of select="position()" /> = new google.maps.InfoWindow({
                                content: contentString
                             });
                             <!-- hier wird der jeweilige Marker mit dem Infofenster verbunden: wenn auf den Marker geklickt wird, soll das Fenster geöffnet werden
                              - position()-Angaben fungieren als Marker-/Fenster-ID
                             -->
                             google.maps.event.addListener(marker<xsl:value-of select="position()" />, 'click', function() {
                                infowindow<xsl:value-of select="position()" />.open(map,marker<xsl:value-of select="position()" />);
                             });
                         </xsl:for-each>
                    }
                </script>
            </head>
            <!-- das HTML-Body-Element braucht den Eventhandler onload und als Wert den Namen der Javascript-Funktion, die wir oben definiert haben (hier: initialize()), 
                damit beim Aufruf der Seite die Karte generiert wird -->
            <body onload="initialize()">
                <!-- Container-Element, in dem die Karte erscheinen soll
                    - Breite und Höhe müssen festgelegt werden
                    - auf die ID wird oben im Javascript verwiesen
                -->
                <div id="container_karte" style="width: 800px; height: 600px;"></div>
            </body>
        </html>
        
    </xsl:template>
</xsl:stylesheet>