<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs tei" version="2.0"> <!-- Man beachte den TEI-Namespace! Ohne den läuft gar nichts! -->
    <xsl:output method="xhtml" /> <!-- die output-Methode ist nicht unwichtig! Sonst schreibt der Prozessor HTML raus, das kein valides xml ist und dann kriegt der Prozessor Schwierigkeiten bei der nächsten Transformation -->
    <!-- Pseudocode 
            bilde eine Variable, in der die Ortsnennungen in den verschiedenen Dokumenten eingesammelt werden
            gehe durch das Ortsregister, bilde Gruppen nach Anfangsbuchstaben, gehe die Gruppen durch und die Orte
            schreib was schönes raus
    -->
    <xsl:template match="/">
        <xsl:variable name="ortsvorkommen"> <!-- zunächst werden alle Vorkommen eingesammelt und ihre Daten in eine Variable gepackt -->
            <xsl:for-each select="collection('.')//tei:body//tei:placeName[not (@ref)]"> <!-- collection() grast ganze Ordner ab -->
                <ortsnennung>
                    <lokalerName><xsl:value-of select="replace(.,'=(\s)*','')"/></lokalerName>  <!-- replace() haut bei den originalen Schreibungen die Trennungszeichen am Zeilenende raus -->
                    <key><xsl:value-of select="@key"/></key>
                    <datei><xsl:value-of select="ancestor::tei:TEI/tei:teiHeader//tei:titleStmt/substring-before(tei:author[1],',')"/></datei>
                    <seite><xsl:value-of select="preceding::tei:pb[1]/@n"/></seite>
                </ortsnennung>
            </xsl:for-each>
        </xsl:variable>
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></meta>
            </head>
            <body>
                <xsl:for-each-group select="//tei:listPlace//tei:placeName" group-by="substring(.,1,1)"> <!-- gehe das Ortsregister durch, Bilde Gruppen nach den Anfangsbuchstaben -->
                    <h1><xsl:value-of select="current-grouping-key()"/></h1> <!-- Überschriften für die Hauptbuchstaben -->
                    <xsl:for-each select="current-group()"> <!-- alle Orte gleichen Anfangsbuchstabens -->
                        <xsl:sort select="."/>
                        <xsl:variable name="current-name" select="."/> <!--  den Namen brauchen wir später noch für Vergleiche -->
                        <xsl:variable name="current-key" select="../@xml:id"/> <!--  den key brauchen wir später noch für Vergleiche -->
                        <p><b><xsl:value-of select="."/>: </b>
                            <xsl:for-each-group select="$ortsvorkommen//ortsnennung[key=$current-key]" group-by="datei"> <!-- die Vorkommnisse werden nach Dokumenten gruppiert -->
                                <xsl:value-of select="datei"/> 
                                <xsl:for-each-group select="current-group()" group-by="lokalerName"> <!-- die orkommnisse werden nach der Schreibung gruppiert -->
                                    <xsl:for-each select="current-group()"> <!-- alle Vorkommnisse für diese Schreibung -->
                                        <xsl:text> </xsl:text><a href="LinkBauen">S.<xsl:value-of select="seite"/></a><xsl:if test="position() != last()">,</xsl:if>    
                                    </xsl:for-each>
                                    <xsl:if test="lokalerName != $current-name"> (<xsl:value-of select="lokalerName"/>)</xsl:if> <!-- lokale Schreibung nur ausgeben, wenn sie von der Normschreibung abweicht -->
                                </xsl:for-each-group><xsl:if test="position() != last()">; </xsl:if>
                            </xsl:for-each-group>
                        </p>
                    </xsl:for-each>
                </xsl:for-each-group>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>